Package: diversityArch
Type: Package
Title: Computes Diversity Indices with Archaeological Data
Version: 0.3.0
Authors@R: c(
    person(
      "Andreu", "Sansó",
      email = "andreu.sanso@uib.eu",
      role = c("aut", "cre")
    ),
    person(
      "Arnaud", "Barat",
      email = "abarat@iphes.cat",
      role = c("aut")
    ),
    person(
      "Jordi", "Rosell",
      email = "jordirosellardevol@gmail.com",
      role = c("aut")
    )
  )
Description: Companion package of Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2025), "Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave".
License: GPL-2
Imports: methods
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-04 16:28:32 UTC; HP
Author: Andreu Sansó [aut, cre],
  Arnaud Barat [aut],
  Jordi Rosell [aut]
Maintainer: Andreu Sansó <andreu.sanso@uib.eu>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2026-05-04 17:00:02 UTC
Built: R 4.5.2; ; 2026-05-04 21:49:51 UTC; unix

Package: diversityArch
Type: Package
Title: Computes Diversity Indices for Archaeological Data
Version: 0.4.0
Authors@R: c(
    person(
      "Andreu", "Sansó",
      email = "andreu.sanso@uib.eu",
      role = c("aut", "cre")
    ),
    person(
      "Arnaud", "Barat",
      email = "abarat@iphes.cat",
      role = c("aut")
    ),
    person(
      "Jordi", "Rosell",
      email = "jordirosellardevol@gmail.com",
      role = c("aut")
    )
  )
Description: Companion package of Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>. It computes Diversity Indices, decomposes several of them and computes bootstrap confidence intervals.
License: GPL-2
Imports: methods
Encoding: UTF-8
LazyData: true
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-13 09:51:24 UTC; UIB
Author: Andreu Sansó [aut, cre],
  Arnaud Barat [aut],
  Jordi Rosell [aut]
Maintainer: Andreu Sansó <andreu.sanso@uib.eu>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2026-06-13 10:10:02 UTC

importFrom("stats", "na.omit")
importFrom("methods", "is")
export("all_indices")
export("bs")
export("bs_dec")
export("bs_frag")
export("dec_equit")
export("dec_shannon")
export("dominance")
export("equitability")
export("evenness")
export("margalef")
export("menhinick")
export("shannon")
export("shannon_frag")
export("simpson_D")
export("simpson_E")

#' @title Diversity indices
#'
#' @description Computes and prints all the diversity indices
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#' @param groups Vector of dimension S of factors indicating the groups. If omitted, the decomposition of the indicators is not done.
#' @param B Number of bootstrap samples. The default is 1000.
#' @param cl Confidence level. A value between 0 and 1. The default is 0.95.
#'
#' @return{No return value. It prints the value of all indicators}
#'
#' @seealso \link{shannon}, \link{dec_shannon}, \link{dominance}, \link{equitability}, \link{evenness}, \link{margalef}, \link{menhinick}, \link{simpson_D}, \link{simpson_E}
#'
#' @references
#' "Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026): Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing  at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' all_indices(Qesem_s$HU)
#' all_indices(Qesem_s$HU, Qesem_s$Group)
#'
#' @export
all_indices <- function(x, groups = NULL, B = 1000, cl = 0.95){
  cat("\n")
  b <- bs(x, ind = "shannon", B = B, cl = cl)
  if (!is.null(groups)) {
    sh <- dec_shannon(x, groups)
    cat("Shannon's diversity (Total):", sh$shannon, "  (", b$low,",", b$up,")\n")
    b <- bs_dec(x, groups, ind = "shannon", B = B, cl = cl)
    cat("Decomposing Shannon's diversity:\n")
    cat("    Within groups: ", sh$within, "  (", b$wt_low,",", b$wt_up,")\n")
    cat("    Between groups:", sh$between, "  (", b$bt_low,",", b$bt_up,")\n")
    cat("    Fraction Between/Total:", sh$between/sh$shannon,"\n")
    cat("  Entropy within each group\n")
    print(sh$g)
    cat("\n")
  } else {
    cat("Shannon's diversity:", shannon(x), "  (", b$low,",", b$up,")\n")
  }
  b <- bs(x, ind = "equitability", B = B, cl = cl)
  cat("Equitability (J Pielou):", equitability(x), "  (", b$low,",", b$up,")\n")
  b <- bs(x, ind = "simpson_D", B = B, cl = cl)
  cat("Simpson's dominance:", simpson_D(x), "  (", b$low,",", b$up,")\n")
  b <- bs(x, ind = "dominance", B = B, cl = cl)
  cat("Dominance:", dominance(x), "  (", b$low,",", b$up,")\n")
  b <- bs(x, ind = "simpson_E", B = B, cl = cl)
  cat("Simpson's evenness:", simpson_E(x), "  (", b$low,",", b$up,")\n")
  b <- bs(x, ind = "evenness", B = B, cl = cl)
  cat("Evenness:", evenness(x), "  (", b$low,",", b$up,")\n")
  b <- bs(x, ind = "menhinick", B = B, cl = cl)
  cat("Menhinick's Index:", menhinick(x), "  (", b$low,",", b$up,")\n")
  b <- bs(x, ind = "margalef", B = B, cl = cl)
  cat("Margalef's Index:", margalef(x), "  (", b$low,",", b$up,")\n\n")
  cat("Bootstrap confidence intervals at", cl,"confidence level between ()\n")
}

#' @title Diversity indices
#'
#' @description Computes and prints all the diversity indices
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species (in this case the Margalef and Menhinick indices and bootstrap intervals are not computed). NA values are allowed.
#' @param groups Vector of dimension S of factors indicating the groups. If omitted, the decomposition of the indicators is not done.
#' @param B Number of bootstrap samples. The default value is 1000.
#' @param cl Confidence level. A value between 0 and 1. The default value is 0.95.
#'
#' @return{No return value. It prints the value of all indicators}
#'
#' @seealso \link{shannon}, \link{dec_shannon}, \link{dominance}, \link{equitability}, \link{evenness}, \link{margalef}, \link{menhinick}, \link{simpson_D}, \link{simpson_E}
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' all_indices(Qesem_s$HU)
#' all_indices(Qesem_s$HU, Qesem_s$Group)
#'
#' @export
all_indices <- function(x, groups = NULL, B = 1000, cl = 0.95){
  xx <- check_x(x)
  if (sum(xx) !=1){
    cat("\n")
    b <- bs(x, ind = "shannon", B = B, cl = cl)
    if (!is.null(groups)) {
      sh <- dec_shannon(x, groups)
      cat("Shannon's diversity (Total):", sh$shannon, "  (", b$ci[1],",", b$ci[2],")\n")
      b <- bs_dec(x, groups, B = B, cl = cl)
      cat("Decomposing Shannon's diversity:\n")
      cat("    Within groups: ", sh$within, "  (", b$ci_wt[1],",", b$ci_wt[2],")\n")
      cat("    Between groups:", sh$between, "  (", b$ci_bt[1],",", b$ci_bt[2],")\n")
      cat("    Fraction Between/Total:", sh$between/sh$shannon,"\n")
      cat("  Entropy within each group\n")
      print(sh$g)
      cat("\n")
    } else {
      cat("Shannon's diversity:", shannon(x), "  (", b$ci[1],",", b$ci[2],")\n")
    }
    b <- bs(x, ind = "equitability", B = B, cl = cl)
    cat("Equitability (J Pielou):", equitability(x), "  (", b$ci[1],",", b$ci[2],")\n")
    b <- bs(x, ind = "simpson_D", B = B, cl = cl)
    cat("Simpson's dominance:", simpson_D(x), "  (", b$ci[1],",", b$ci[2],")\n")
    b <- bs(x, ind = "dominance", B = B, cl = cl)
    cat("Dominance:", dominance(x), "  (", b$ci[1],",", b$ci[2],")\n")
    b <- bs(x, ind = "simpson_E", B = B, cl = cl)
    cat("Simpson's evenness:", simpson_E(x), "  (", b$ci[1],",", b$ci[2],")\n")
    b <- bs(x, ind = "evenness", B = B, cl = cl)
    cat("Evenness:", evenness(x), "  (", b$ci[1],",", b$ci[2],")\n")
    b <- bs(x, ind = "menhinick", B = B, cl = cl)
    cat("Menhinick's Index:", menhinick(x), "  (", b$ci[1],",", b$ci[2],")\n")
    b <- bs(x, ind = "margalef", B = B, cl = cl)
    cat("Margalef's Index:", margalef(x), "  (", b$ci[1],",", b$ci[2],")\n")
    cat("\nBootstrap confidence intervals at", cl,"confidence level between ()\n")
  } else {
    cat("\n")
    if (!is.null(groups)) {
      sh <- dec_shannon(x, groups)
      cat("Shannon's diversity (Total):", sh$shannon, "\n")
      cat("Decomposing Shannon's diversity:\n")
      cat("    Within groups: ", sh$within, "\n")
      cat("    Between groups:", sh$between, "\n")
      cat("    Fraction Between/Total:", sh$between/sh$shannon,"\n")
      cat("  Entropy within each group\n")
      print(sh$g)
      cat("\n")
    } else {
      cat("Shannon's diversity:", shannon(x), "\n")
    }
    cat("Equitability (J Pielou):", equitability(x), "\n")
    cat("Simpson's dominance:", simpson_D(x), "\n")
    cat("Dominance:", dominance(x), "\n")
    cat("Simpson's evenness:", simpson_E(x), "\n")
    cat("Evenness:", evenness(x), "\n")
  }
}

#' @title Shannon diversity index
#'
#' @description Computes Shannon's diversity index
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#'
#' @return Shannon's diversity index (Entropy).
#'
#' @seealso \link{dec_shannon}, \link{equitability}
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' shannon(Qesem_s$HU)
#'
#' @export
shannon <- function(x){
  x <- check_x(x)
  p <- x/sum(x)
  return(sum(-p*log(p)))
}

#' @title Shannon diversity decomposition
#'
#' @description Computes Shannon diversity and its decomposition
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#' @param groups Vector of dimension S of factors indicating the group of each species.
#'
#' @return
#' \itemize{
#'   \item \code{shannon}: Shannon's total Entropy.
#'   \item \code{within}: Within groups entropy.
#'   \item \code{between}: Between groups entropy.
#'   \item \code{groups}: A data frame with information about each group: relative frequency, internal entropy and number of species.
#' }
#'
#' @seealso \link{shannon}
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' dec_shannon(Qesem_s$HU, Qesem_s$Group)
#'
#' @export
dec_shannon <- function(x, groups){
  stopifnot(
    length(x)==length(as.character(groups)),
    is.factor(groups)
  )
  x <- ifelse(x==0, NA, x)
  xx <- na.omit(data.frame(x, groups))
  stopifnot(
    is.numeric(xx$x),
    all(xx$x > 0),
    isTRUE(all.equal(xx$x, round(xx$x)))
  )
  p <- xx$x/sum(xx$x)
  l <- levels(xx$groups)
  m <- length(l)
  P <- numeric(m)
  Hg <- numeric(m)
  S <- numeric(m)
  for (i in 1:m){
    P[i] <- sum(p[xx$groups==l[i]])
    Hg[i] <- -sum(p[xx$groups==l[i]]/P[i]*log(p[xx$groups==l[i]]/P[i]))
    S[i] <- sum(xx$groups==l[i])
  }
  g <- data.frame(group=l, Prop=P, Entropy=Hg, S=S)
  rownames(g) <- NULL
  return(list(shannon = -sum(p*log(p)),
              within = sum(P*Hg),
              between = -sum(P*log(P)),
              groups = g))
}

test_that(
  "Decomposition of Shannon Entropy. Returns 0.17038",
  {
    expected <- 0.16768
    data(Qesem_s)
    actual <- dec_shannon(Qesem_s$HU, Qesem_s$Group)$within
    expect_equal(round(actual,5), round(expected,5))
  }
)

#' @title Shannon diversity decomposition
#'
#' @description Computes Shannon diversity and its decomposition
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species. NA values are allowed.
#' @param groups Vector of dimension S of factors indicating the group of each species.
#'
#' @return
#' \itemize{
#'   \item \code{shannon}: Shannon's total Entropy.
#'   \item \code{within}: Within groups entropy.
#'   \item \code{between}: Between groups entropy.
#'   \item \code{groups}: A data frame with information about each group: relative frequency, internal entropy and number of species.
#' }
#'
#' @seealso \link{shannon}
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' dec_shannon(Qesem_s$HU, Qesem_s$Group)
#'
#' @export
dec_shannon <- function(x, groups){
  stopifnot(
    length(x)==length(as.character(groups)),
    is.factor(groups)
  )
  x <- ifelse(x==0, NA, x)
  xx <- na.omit(data.frame(x, groups))
  stopifnot(
    is.numeric(xx$x),
    all(xx$x > 0)
  )
  p <- xx$x/sum(xx$x)
  l <- levels(xx$groups)
  m <- length(l)
  P <- numeric(m)
  Hg <- numeric(m)
  S <- numeric(m)
  for (i in 1:m){
    P[i] <- sum(p[xx$groups==l[i]])
    Hg[i] <- -sum(p[xx$groups==l[i]]/P[i]*log(p[xx$groups==l[i]]/P[i]))
    S[i] <- sum(xx$groups==l[i])
  }
  g <- data.frame(group=l, Prop=P, Entropy=Hg, S=S)
  rownames(g) <- NULL
  return(list(shannon = -sum(p*log(p)),
              within = sum(P*Hg),
              between = -sum(P*log(P)),
              groups = g))
}

#' @title Bootstrap estimates of the diversity indices
#'
#' @description Computes bootstrap standard error and confidence interval of the diversity indices
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#' @param ind Index to be computed. The default value is "shannon". Other possible values are: "simpson_E", "simpson_D", "menhinick", "margalef", "evenness", "equitability" and "dominance".
#' @param B Number of bootstrap samples. The default is 1000.
#' @param cl Confidence level. A value between 0 and 1. The default is 0.95.
#'
#' @return
#' \itemize{
#'   \item \code{s}: Boostrap standard error.
#'   \item \code{low}: Lower limit of the confidence interval.
#'   \item \code{up}: Upper limit of the confidence interval.
#' }
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' bs(Qesem_s$HU)
#'
#' @export
bs <- function(x, ind = "shannon", B = 1000, cl = 0.95){
  x <- check_x(x)
  stopifnot(is.numeric(B),
            B==round(B),
            cl>0 & cl<1,
            ind %in% c("shannon", "simpson_E", "simpson_D", "menhinick",
                       "margalef", "evenness", "equitability", "dominance")
            )
  n <- sum(x)
  p <- x/n
  m <- length(x)
  y <- numeric(B)
  for (i in 1:B){
    xx <- sample(1:m, n, replace = T, prob = p)
    xb <- as.vector(table(xx))
    y[i] <- switch(ind,
                   shannon = shannon(xb),
                   simpson_E = simpson_E(xb),
                   simpson_D = simpson_D(xb),
                   menhinick = menhinick(xb),
                   margalef = margalef(xb),
                   evenness = evenness(xb),
                   equitability = equitability(xb),
                   dominance = dominance(xb)
                   )
  }
  q <- stats::quantile(y, probs = sort(c(1-cl, cl)))
  return(list(s = stats::sd(y),
              low = as.numeric(q[1]),
              up = as.numeric(q[2])
              )
         )
}

#' @title Bootstrap estimates of the diversity indices
#'
#' @description Computes bootstrap standard error and confidence interval of the diversity indices
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed.
#' @param ind Index to be computed. The default value is "shannon". Other possible values are: "simpson_E", "simpson_D", "menhinick", "margalef", "evenness", "equitability" and "dominance".
#' @param B Number of bootstrap samples. The default is 1000.
#' @param cl Confidence level. A value between 0 and 1. The default is 0.95.
#'
#' @return
#' \itemize{
#'   \item \code{s}: Boostrap standard error.
#'   \item \code{ci}: Confidence interval.
#' }
#'
#' @seealso \link{shannon}, \link{dec_shannon}, \link{dominance}, \link{equitability}, \link{evenness}, \link{margalef}, \link{menhinick}, \link{simpson_D}, \link{simpson_E}
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' bs(Qesem_s$HU)
#'
#' @export
bs <- function(x, ind = "shannon", B = 1000, cl = 0.95){

  x <- check_x(x)
  stopifnot(is.numeric(B),
            B==round(B),
            cl>0 & cl<1,
            ind %in% c("shannon", "simpson_E", "simpson_D", "menhinick",
                       "margalef", "evenness", "equitability", "dominance")
            )

  n <- sum(x)
  p <- x/n
  m <- length(x)
  y <- numeric(B)
  for (i in 1:B){
    xx <- sample(1:m, n, replace = T, prob = p)
    xb <- as.vector(table(xx))
    y[i] <- switch(ind,
                   shannon = shannon(xb),
                   simpson_E = simpson_E(xb),
                   simpson_D = simpson_D(xb),
                   menhinick = menhinick(xb),
                   margalef = margalef(xb),
                   evenness = evenness(xb),
                   equitability = equitability(xb),
                   dominance = dominance(xb)
                   )
  }

  alpha <- 1-cl
  q <- unname(stats::quantile(y, probs = sort(c(alpha/2, 1-alpha/2))))

  return(list(s = stats::sd(y), ci = q)          )
}

#' @title Bootstrap estimates of the decomposed diversity indices
#'
#' @description Computes bootstrap confidence intervals of the decomposed diversity indices
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#' @param groups Vector of dimension S of factors indicating the groups of each species.
#' @param ind Index to be computed. The default value is "shannon". The other possible value is "equitability".
#' @param B Number of bootstrap samples. The default is 1000.
#' @param cl Confidence level. A value between 0 and 1. The default is 0.95.
#'
#' @return
#' \itemize{
#'   \item \code{bt_low}: Lower limit of the confidence interval for "between groups".
#'   \item \code{bt_up}: Upper limit of the confidence interval for "between groups".
#'   \item \code{wt_low}: Lower limit of the confidence interval for "within groups".
#'   \item \code{bt_up}: Upper limit of the confidence interval for "within groups".
#' }
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' bs_dec(Qesem_s$HU, Qesem_s$Group)
#'
#' @export
bs_dec <- function(x, groups, ind = "shannon", B = 1000, cl = 0.95){
  stopifnot(is.numeric(B),
            B==round(B),
            cl>0 & cl<1,
            ind %in% c("shannon", "equitability"),
            length(x)==length(as.character(groups)),
            is.factor(groups)
            )
  x <- ifelse(x==0, NA, x)
  xx <- na.omit(data.frame(x, groups))
  stopifnot(
    is.numeric(xx$x),
    all(xx$x > 0),
    isTRUE(all.equal(xx$x, round(xx$x)))
    )
  n <- sum(xx$x)
  m <- nrow(xx)
  for (i in 1:m){
    if (i==1) y <- data.frame(S=rep(i, xx$x[i]),
                              G=rep(xx$groups[i], xx$x[i]))
    else y <- rbind(y, data.frame(S=rep(i, xx$x[i]),
                                  G=rep(xx$groups[i], xx$x[i])))
  }
  res <- data.frame(bt=rep(NA, B), wt=rep(NA, B))
  for (i in 1:B){
    s <- sample(1:n, n, replace = T)
    yb <- y[s,]
    tab <- table(yb$S)
    if (ind=="shannon"){
      d <- dec_shannon(as.vector(tab), xx$groups[as.numeric(names(tab))])
      res$bt[i] <- d$between
      res$wt[i] <- d$within
    } else {
      d <- dec_equit(as.vector(tab), xx$groups[as.numeric(names(tab))])
      res$bt[i] <- d$between
      res$wt[i] <- d$within
    }
  }
  q_bt <- stats::quantile(res$bt, probs = sort(c(1-cl, cl)))
  q_wt <- stats::quantile(res$wt, probs = sort(c(1-cl, cl)))
  return(list(bt_low = as.numeric(q_bt[1]),
              bt_up = as.numeric(q_bt[2]),
              wt_low = as.numeric(q_wt[1]),
              wt_up = as.numeric(q_wt[2])
              )
         )

}

#' @title Bootstrap estimates of the decomposed Shannon's diversity index
#'
#' @description Computes bootstrap confidence intervals of the Shannon's diversity index
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed.
#' @param groups Vector of dimension S of factors indicating the groups of each species.
#' @param B Number of bootstrap samples. The default is 1000.
#' @param cl Confidence level. A value between 0 and 1. The default is 0.95.
#'
#' @return
#' \itemize{
#'   \item \code{ci_bt}: Confidence interval for "between groups".
#'   \item \code{ci_wt}: Confidence interval for "within groups".
#' }
#'
#' @seealso \link{shannon}, \link{dec_shannon}
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' bs_dec(Qesem_s$HU, Qesem_s$Group)
#'
#' @export
bs_dec <- function(x, groups, B = 1000, cl = 0.95){
  stopifnot(is.numeric(B),
            B==round(B),
            cl>0 & cl<1,
            length(x)==length(as.character(groups))
            )
  groups <- as.factor(groups)
  ok <- !is.na(x) & x > 0 & !is.na(groups)
  x <- x[ok]
  groups <- droplevels(groups[ok])

  n <- sum(x)
  p <- x / n

  decomp_once <- function(counts, groups) {
    ok <- !is.na(counts) & counts > 0 & !is.na(groups)
    counts <- counts[ok]
    groups <- droplevels(groups[ok])

    p <- counts / sum(counts)
    P <- tapply(p, groups, sum)

    # between-group component
    bt <- -sum(P[P > 0] * log(P[P > 0]))

    # within-group component
    wt <- 0
    levs <- names(P)
    for (lv in levs) {
      idx <- groups == lv
      Pg <- P[lv]
      if (Pg > 0) {
        q <- p[idx] / Pg
        wt <- wt - Pg * sum(q[q > 0] * log(q[q > 0]))
      }
    }

    c(bt, wt)
  }

  res <- matrix(NA_real_, nrow = 2, ncol = B)
  rownames(res) <- c("bt", "wt")

  # bootstrap replications
  for (b in seq_len(B)) {
    counts_b <- as.vector(stats::rmultinom(1, size = n, prob = p))
    res[, b] <- decomp_once(counts_b, groups)
  }

  bt_valid <- res["bt", is.finite(res["bt", ])]
  wt_valid <- res["wt", is.finite(res["wt", ])]

  alpha <- 1 - cl
  probs <- sort(c(alpha / 2, 1 - alpha / 2))

  return(list(ci_bt = unname(stats::quantile(bt_valid, probs = probs, na.rm = TRUE)),
              ci_wt = unname(stats::quantile(wt_valid, probs = probs, na.rm = TRUE))
              )
         )
}

#' @title Simpson's evenness index
#'
#' @description Computes Simpson's evenness index.
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#'
#' @return Simpson's evenness index.
#'
#' @seealso \link{evenness}, \link{simpson_D}
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' simpson_E(Qesem_s$HU)
#'
#' @export
simpson_E <- function(x){
  return(1-simpson_D(x))
}

#' @title Equitability. J Pielou index
#'
#' @description Computes J Pielou index know as equitability
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#'
#' @return Equitability. J Pielou index.
#'
#' @seealso \link{shannon}
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' equitability(Qesem_s$HU)
#'
#' @export
equitability <- function(x){               # J (Pielou)
  x <- check_x(x)
  return(shannon(x)/log(length(x)))
}

#' @title Simpson's evenness index
#'
#' @description Computes Simpson's evenness index.
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species. NA values are allowed.
#'
#' @return Simpson's evenness index.
#'
#' @seealso \link{evenness}, \link{simpson_D}
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' simpson_E(Qesem_s$HU)
#'
#' @export
simpson_E <- function(x){
  return(1-simpson_D(x))
}

#' @title Check input
#'
#' @description Checks if x is a proper input
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#'
#' @return x without NA or 0 values
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @keywords internal
check_x  <- function(x){
  x <- stats::na.omit(x)
  stopifnot(is.numeric(x))
  x <- ifelse(x==0, NA, x)
  x <- stats::na.omit(x)
  stopifnot(
    all(x >0),
    isTRUE(all.equal(x, round(x)))
  )
  return(x)
}

#' @title Check input
#'
#' @description Checks if x is a proper input
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species. NA values are allowed.
#'
#' @return x without NA or 0 values
#'
#' @keywords internal
check_x  <- function(x){
  x <- stats::na.omit(x)
  stopifnot(is.numeric(x))
  x <- ifelse(x==0, NA, x)
  x <- stats::na.omit(x)
  stopifnot(all(x >0))
  if (sum(x) !=1)  stopifnot(isTRUE(all.equal(x, round(x))))
  return(x)
}

#' @title Decomposition of the equitability index
#'
#' @description Computes equitability and its decomposition
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#' @param groups Vector of dimension S of factors indicating the group of each species.
#'
#' @return
#' \itemize{
#'   \item \code{equitability}: Equitability index.
#'   \item \code{within}: Within groups equitability.
#'   \item \code{between}: Between groups equitability.
#' }
#'
#' @seealso \link{dec_shannon}
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' dec_equit(Qesem_s$HU, Qesem_s$Group)
#'
#' @export

# function to compute equitability and its decomposition
dec_equit <- function(x, groups){
  d <- dec_shannon(x, groups)
  g <- d$groups
  S <- sum(g$S)
  return(list(equitability = equitability(x),
              within = d$within/log(S),
              between = d$between/log(S)))
}

#' @title Decomposition of the equitability index
#'
#' @description Computes equitability and its decomposition
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species. NA values are allowed.
#' @param groups Vector of dimension S of factors indicating the group of each species.
#'
#' @return
#' \itemize{
#'   \item \code{equitability}: Equitability index.
#'   \item \code{within}: Within groups equitability.
#'   \item \code{between}: Between groups equitability.
#' }
#'
#' @seealso \link{dec_shannon}
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' dec_equit(Qesem_s$HU, Qesem_s$Group)
#'
#' @export

# function to compute equitability and its decomposition
dec_equit <- function(x, groups){
  d <- dec_shannon(x, groups)
  g <- d$groups
  S <- sum(g$S)
  return(list(equitability = equitability(x),
              within = d$within/log(S),
              between = d$between/log(S)))
}

#' @title Dominance index
#'
#' @description Modification of the Simpson's dominance index to be restricted between 0 and 1.
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#'
#' @return Dominance index (Modified Simpson's dominance index).
#'
#' @seealso \link{simpson_D}
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' dominance(Qesem_s$HU)
#'
#' @export
dominance <- function(x){
  x <- check_x(x)
  S <- length(x)
  return((S*simpson_D(x)-1)/(S-1))
}

#' @title Margalef index
#'
#' @description Computes Margalef's index
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#'
#' @return Margalef index.
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' margalef(Qesem_s$HU)
#'
#' @export
margalef  <- function(x){
  x <- check_x(x)
  return((length(x)-1)/log(sum(x)))
}

#' @title Shannon diversity decomposition
#'
#' @description Computes Shannon diversity and its decomposition
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#' @param gx Vector of dimension S of factors indicating the group of each species. G groups.
#' @param f Vector of dimension G with the number (>0) of fragments in each group
#' @param gf Vector of dimension G of factors indicating the groups to which the fragments "f" belong.
#'
#' @return
#' \itemize{
#'   \item \code{shannon}: Shannon's total Entropy.
#'   \item \code{within}: Within groups entropy.
#'   \item \code{between}: Between groups entropy.
#'   \item \code{groups}: A data frame with information about each group: relative frequency, internal entropy and number of species.
#' }
#'
#' @seealso \link{shannon}
#'
#' @references
#' "Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
#'
#' @examples
#' data(Qesem_s)
#' data(Qesem_f)
#' shannon_frag(Qesem_s$HU, Qesem_s$Group, Qesem_f$HU, Qesem_f$Group)
#'
#' @export
shannon_frag <- function(x, gx, f, gf){
  stopifnot(length(x)==length(as.character(gx)),
            length(f)==length(levels(gx)),
            length(f)==length(as.character(gf)),
            is.factor(gx),
            is.factor(gf),
            is.numeric(f),
            all(f > 0),
            isTRUE(all.equal(f, round(f)))
  )
  x <- ifelse(x==0, NA, x)
  xx <- stats::na.omit(data.frame(x, gx))
  stopifnot(
    is.numeric(xx$x),
    all(xx$x > 0),
    isTRUE(all.equal(xx$x, round(xx$x)))
  )

  d <- dec_shannon(xx$x, xx$gx)
  g <- d$groups
  l <- levels(xx[,2])
  k <- length(l)
  y <- numeric(k)
  Hg <- numeric(k)
  for (i in 1:k){
    y[i] <- as.numeric(sum(xx[xx[,2]==l[i],1]) + f[gf==l[i]])
    Hg[i] <- g[g[,1]==l[i],3]
  }
  P <- y/sum(y)
  b <- -sum(P*log(P))
  w <- sum(P*Hg)
  gg <- data.frame(group=l, Prop=P, Entropy=Hg, S=g$S)
  rownames(gg) <- NULL

  return(list(shannon = w + b,
              within = w,
              between = b,
              groups = gg))
}

test_that(
  "Shannon index with fragmentari data. Returns 0.92707",
  {
    expected <- 0.9269
    data(Qesem_s)
    data(Qesem_f)
    actual <- shannon_frag(Qesem_s$HU, Qesem_s$Group,
                           Qesem_f$HU, Qesem_f$Group)$between
    expect_equal(round(actual,5), round(expected,5))
  }
)

#' @title Menhinick index
#'
#' @description Computes Menhinick's index
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed.
#'
#' @return Menhinick index.
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' menhinick(Qesem_s$HU)
#'
#' @export
menhinick <- function(x){
  x <- check_x(x)
  return(length(x)/sqrt(sum(x)))
}

#' @title Shannon diversity decomposition
#'
#' @description Computes Shannon diversity and its decomposition
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.
#' @param gx Vector of dimension S of factors indicating the group of each species. G groups.
#' @param f Vector of dimension G with the number (>0) of fragments in each group
#' @param gf Vector of dimension G of factors indicating the groups to which the fragments "f" belong.
#'
#' @return
#' \itemize{
#'   \item \code{shannon}: Shannon's total Entropy.
#'   \item \code{within}: Within groups entropy.
#'   \item \code{between}: Between groups entropy.
#'   \item \code{groups}: A data frame with information about each group: relative frequency, internal entropy and number of species.
#' }
#'
#' @seealso \link{shannon}
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' data(Qesem_f)
#' shannon_frag(Qesem_s$HU, Qesem_s$Group, Qesem_f$HU, Qesem_f$Group)
#'
#' @export
shannon_frag <- function(x, gx, f, gf){
  stopifnot(length(x)==length(as.character(gx)),
            length(f)==length(levels(gx)),
            length(f)==length(as.character(gf)),
            is.factor(gx),
            is.factor(gf),
            is.numeric(f),
            all(f >= 0),
            isTRUE(all.equal(f, round(f)))
  )
  x <- ifelse(x==0, NA, x)
  xx <- stats::na.omit(data.frame(x, gx))
  stopifnot(
    is.numeric(xx$x),
    all(xx$x > 0),
    isTRUE(all.equal(xx$x, round(xx$x)))
  )

  d <- dec_shannon(xx$x, xx$gx)
  g <- d$groups
  l <- levels(xx[,2])
  k <- length(l)
  y <- numeric(k)
  Hg <- numeric(k)
  for (i in 1:k){
    y[i] <- as.numeric(sum(xx[xx[,2]==l[i],1]) + f[gf==l[i]])
    Hg[i] <- g[g[,1]==l[i],3]
  }
  P <- y/sum(y)
  b <- -sum(P*log(P))
  w <- sum(P*Hg)
  gg <- data.frame(group=l, Prop=P, Entropy=Hg, S=g$S)
  rownames(gg) <- NULL

  return(list(shannon = w + b,
              within = w,
              between = b,
              groups = gg))
}

#' @title Bootstrap estimates of the decomposed Shannon's diversity index with fragments
#'
#' @description Computes bootstrap confidence intervals of the decomposed Shannon's diversity index using evidence from fragments
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed.
#' @param gx Vector of dimension S of factors indicating the group of each species. G groups.
#' @param f Vector of dimension G with the number (>0) of fragments in each group
#' @param gf Vector of dimension G of factors indicating the groups to which the fragments "f" belong.
#' @param B Number of bootstrap samples. The default is 1000.
#' @param cl Confidence level. A value between 0 and 1. The default is 0.95.
#'
#' @return
#' \itemize{
#'   \item \code{ci_sh}: Confidence interval for Shannon's diversity index with fragments.
#'   \item \code{ci_bt}: Confidence interval for "between groups".
#'   \item \code{ci_wt}: Confidence interval for "within groups".
#' }
#'
#' @seealso \link{shannon}, \link{dec_shannon}, \link{shannon_frag}
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' data(Qesem_f)
#' bs_frag(Qesem_s$HU, Qesem_s$Group, Qesem_f$HU, Qesem_f$Group)
#'
#' @export
bs_frag <- function(x, gx, f, gf, B = 1000, cl = 0.95){
  stopifnot(is.numeric(B),
            B==round(B),
            cl>0 & cl<1,
            length(x)==length(as.character(gx)),
            length(f)==length(as.character(gf))
  )
  gx <- as.factor(gx)
  ok <- !is.na(x) & x > 0 & !is.na(gx)
  x <- x[ok]
  gx <- droplevels(gx[ok])

  N <- sum(x)
  p <- x / N

  gf <- as.factor(gf)
  ok <- !is.na(f) & f > 0 & !is.na(gf)
  f <- f[ok]
  gf <- droplevels(gf[ok])

  Nf <- sum(f)
  Pf <- f / Nf

  decomp_once <- function(counts, gx, cf, gf) {
    ok <- !is.na(counts) & counts > 0 & !is.na(gx)
    counts <- counts[ok]
    gx <- droplevels(gx[ok])

    p <- counts / sum(counts)
    P <- tapply(p, gx, sum)
    Nc <- tapply(counts, gx, sum)

    # fragmentary evidence
    ok <- !is.na(cf) & cf > 0 & !is.na(gf)
    cf <- cf[ok]
    gf <- droplevels(gf[ok])
    b1 <- data.frame(Nc=Nc, g=as.factor(names(Nc)))
    b2 <- data.frame(Nf=cf, g=gf)
    b <- merge(b1, b2, by = "g", all = TRUE)
    b[is.na(b)] <- 0
    Pc <- (b$Nc + b$Nf)/sum(b$Nc + b$Nf)
    names(Pc) <- names(P)

    # between-group component
    bt <- -sum(Pc[Pc > 0] * log(Pc[Pc > 0]))

    # within-group component
    wt <- 0
    levs <- names(P)
    for (lv in levs) {
      idx <- gx == lv
      Pg <- P[lv]
      if (Pg > 0) {
        q <- p[idx] / Pg
        wt <- wt - Pc[lv] * sum(q[q > 0] * log(q[q > 0]))
      }
    }
    sh <- bt + wt

    c(sh, bt, wt)
  }

  res <- matrix(NA_real_, nrow = 3, ncol = B)
  rownames(res) <- c("sh", "bt", "wt")

  # bootstrap replications
  for (b in seq_len(B)) {
    counts <- as.vector(stats::rmultinom(1, size = N, prob = p))
    cf <- as.vector(stats::rmultinom(1, size = Nf, prob = Pf))
    res[, b] <- decomp_once(counts, gx, cf, gf)
  }

  sh_valid <- res["sh", is.finite(res["sh", ])]
  bt_valid <- res["bt", is.finite(res["bt", ])]
  wt_valid <- res["wt", is.finite(res["wt", ])]

  alpha <- 1 - cl
  probs <- sort(c(alpha / 2, 1 - alpha / 2))

  return(list(ci_sh = unname(stats::quantile(sh_valid, probs = probs, na.rm = TRUE)),
              ci_bt = unname(stats::quantile(bt_valid, probs = probs, na.rm = TRUE)),
              ci_wt = unname(stats::quantile(wt_valid, probs = probs, na.rm = TRUE))
              )
  )
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dec_equit.R
\name{dec_equit}
\alias{dec_equit}
\title{Decomposition of the equitability index}
\usage{
dec_equit(x, groups)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}

\item{groups}{Vector of dimension S of factors indicating the group of each species.}
}
\value{
\itemize{
  \item \code{equitability}: Equitability index.
  \item \code{within}: Within groups equitability.
  \item \code{between}: Between groups equitability.
}
}
\description{
Computes equitability and its decomposition
}
\examples{
data(Qesem_s)
dec_equit(Qesem_s$HU, Qesem_s$Group)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
\seealso{
\link{dec_shannon}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dec_equit.R
\name{dec_equit}
\alias{dec_equit}
\title{Decomposition of the equitability index}
\usage{
dec_equit(x, groups)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species. NA values are allowed.}

\item{groups}{Vector of dimension S of factors indicating the group of each species.}
}
\value{
\itemize{
  \item \code{equitability}: Equitability index.
  \item \code{within}: Within groups equitability.
  \item \code{between}: Between groups equitability.
}
}
\description{
Computes equitability and its decomposition
}
\examples{
data(Qesem_s)
dec_equit(Qesem_s$HU, Qesem_s$Group)

}
\references{
Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
}
\seealso{
\link{dec_shannon}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bs_frag.R
\name{bs_frag}
\alias{bs_frag}
\title{Bootstrap estimates of the decomposed Shannon's diversity index with fragments}
\usage{
bs_frag(x, gx, f, gf, B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed.}

\item{gx}{Vector of dimension S of factors indicating the group of each species. G groups.}

\item{f}{Vector of dimension G with the number (>0) of fragments in each group}

\item{gf}{Vector of dimension G of factors indicating the groups to which the fragments "f" belong.}

\item{B}{Number of bootstrap samples. The default is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default is 0.95.}
}
\value{
\itemize{
  \item \code{ci_sh}: Confidence interval for Shannon's diversity index with fragments.
  \item \code{ci_bt}: Confidence interval for "between groups".
  \item \code{ci_wt}: Confidence interval for "within groups".
}
}
\description{
Computes bootstrap confidence intervals of the decomposed Shannon's diversity index using evidence from fragments
}
\examples{
data(Qesem_s)
data(Qesem_f)
bs_frag(Qesem_s$HU, Qesem_s$Group, Qesem_f$HU, Qesem_f$Group)

}
\references{
Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
}
\seealso{
\link{shannon}, \link{dec_shannon}, \link{shannon_frag}
}

\name{Qesem_s}
\alias{Qesem_s}
\docType{data}
\title{Data used in the examples}
\description{Data frame with number of bones of different species and diferent levels in Qesem (Israel),
  and a factor related to the size of the animal. Data source: Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., (2024)}
\usage{data(Qesem_s)}
\value{Data frame with 15 observations and 7 levels.}
\source{Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., 2024. Exploring the lack of articular ends at the Middle Pleistocene site of Qesem Cave, Israel. Journal of Human Evolution 189, 103509. doi:10.1016/j.jhevol.2024.103509}
\references{Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I., Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R., Gopher, A. & Rosell-Ardèvol, J., 2025. Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave.
    Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., 2024. Exploring the lack of articular ends at the Middle Pleistocene site of Qesem Cave, Israel. Journal of Human Evolution 189, 103509. doi:10.1016/j.jhevol.2024.103509}
\author{Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A.}
\examples{
data(Qesem_s)
names(Qesem_s)
# The following example replicates some of the results in
# Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I.,
# Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R.,
# Gopher, A. & Rosell-Ardèvol, J., 2025. "Quantifying Diversity through Entropy
# Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave".
all_indices(Qesem_s$HU)
}
\keyword{Datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/margalef.R
\name{margalef}
\alias{margalef}
\title{Margalef index}
\usage{
margalef(x)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed.}
}
\value{
Margalef index.
}
\description{
Computes Margalef's index
}
\examples{
data(Qesem_s)
margalef(Qesem_s$HU)

}
\references{
Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shannon.R
\name{shannon}
\alias{shannon}
\title{Shannon diversity index}
\usage{
shannon(x)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}
}
\value{
Shannon's diversity index (Entropy).
}
\description{
Computes Shannon's diversity index
}
\examples{
data(Qesem_s)
shannon(Qesem_s$HU)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
\seealso{
\link{dec_shannon}, \link{equitability}
}

\name{Qesem_s}
\alias{Qesem_s}
\docType{data}
\title{Data used in the examples}
\description{Data frame with number of bones of different species and diferent levels in Qesem (Israel),
  and a factor related to the size of the animal. Data source: Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., (2024)}
\usage{data(Qesem_s)}
\value{Data frame with 15 observations and 7 levels.}
\source{Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., 2024 <doi:10.1016/j.jhevol.2024.103509>}
\references{Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I., Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R., Gopher, A. & Rosell-Ardèvol, J., 2026 <doi:10.1007/s10816-026-09802-3>.
    Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., 2024 <doi:10.1016/j.jhevol.2024.103509>}
\author{Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A.}
\examples{
data(Qesem_s)
names(Qesem_s)
# The following example replicates some of the results in
# Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I.,
# Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R.,
# Gopher, A. & Rosell-Ardèvol, J. 2026. <doi:10.1007/s10816-026-09802-3>.
all_indices(Qesem_s$HU)
}
\keyword{Datasets}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/all_indices.R
\name{all_indices}
\alias{all_indices}
\title{Diversity indices}
\usage{
all_indices(x, groups = NULL, B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}

\item{groups}{Vector of dimension S of factors indicating the groups. If omitted, the decomposition of the indicators is not done.}

\item{B}{Number of bootstrap samples. The default is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default is 0.95.}
}
\value{
{No return value. It prints the value of all indicators}
}
\description{
Computes and prints all the diversity indices
}
\examples{
data(Qesem_s)
all_indices(Qesem_s$HU)
all_indices(Qesem_s$HU, Qesem_s$Group)

}
\references{
"Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2025): Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing  at Qesem cave"
}
\seealso{
\link{shannon}, \link{dec_shannon}, \link{dominance}, \link{equitability}, \link{evenness}, \link{margalef}, \link{menhinick}, \link{simpson_D}, \link{simpson_E}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shannon_frag.R
\name{shannon_frag}
\alias{shannon_frag}
\title{Shannon diversity decomposition}
\usage{
shannon_frag(x, gx, f, gf)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}

\item{gx}{Vector of dimension S of factors indicating the group of each species. G groups.}

\item{f}{Vector of dimension G with the number (>0) of fragments in each group}

\item{gf}{Vector of dimension G of factors indicating the groups to which the fragments "f" belong.}
}
\value{
\itemize{
  \item \code{shannon}: Shannon's total Entropy.
  \item \code{within}: Within groups entropy.
  \item \code{between}: Between groups entropy.
  \item \code{groups}: A data frame with information about each group: relative frequency, internal entropy and number of species.
}
}
\description{
Computes Shannon diversity and its decomposition
}
\examples{
data(Qesem_s)
data(Qesem_f)
shannon_frag(Qesem_s$HU, Qesem_s$Group, Qesem_f$HU, Qesem_f$Group)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
\seealso{
\link{shannon}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/all_indices.R
\name{all_indices}
\alias{all_indices}
\title{Diversity indices}
\usage{
all_indices(x, groups = NULL, B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species (in this case the Margalef and Menhinick indices and bootstrap intervals are not computed). NA values are allowed.}

\item{groups}{Vector of dimension S of factors indicating the groups. If omitted, the decomposition of the indicators is not done.}

\item{B}{Number of bootstrap samples. The default value is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default value is 0.95.}
}
\value{
{No return value. It prints the value of all indicators}
}
\description{
Computes and prints all the diversity indices
}
\examples{
data(Qesem_s)
all_indices(Qesem_s$HU)
all_indices(Qesem_s$HU, Qesem_s$Group)

}
\references{
Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
}
\seealso{
\link{shannon}, \link{dec_shannon}, \link{dominance}, \link{equitability}, \link{evenness}, \link{margalef}, \link{menhinick}, \link{simpson_D}, \link{simpson_E}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bs_dec.R
\name{bs_dec}
\alias{bs_dec}
\title{Bootstrap estimates of the decomposed diversity indices}
\usage{
bs_dec(x, groups, ind = "shannon", B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}

\item{groups}{Vector of dimension S of factors indicating the groups of each species.}

\item{ind}{Index to be computed. The default value is "shannon". The other possible value is "equitability".}

\item{B}{Number of bootstrap samples. The default is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default is 0.95.}
}
\value{
\itemize{
  \item \code{bt_low}: Lower limit of the confidence interval for "between groups".
  \item \code{bt_up}: Upper limit of the confidence interval for "between groups".
  \item \code{wt_low}: Lower limit of the confidence interval for "within groups".
  \item \code{bt_up}: Upper limit of the confidence interval for "within groups".
}
}
\description{
Computes bootstrap confidence intervals of the decomposed diversity indices
}
\examples{
data(Qesem_s)
bs_dec(Qesem_s$HU, Qesem_s$Group)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shannon_frag.R
\name{shannon_frag}
\alias{shannon_frag}
\title{Shannon diversity decomposition}
\usage{
shannon_frag(x, gx, f, gf)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}

\item{gx}{Vector of dimension S of factors indicating the group of each species. G groups.}

\item{f}{Vector of dimension G with the number (>0) of fragments in each group}

\item{gf}{Vector of dimension G of factors indicating the groups to which the fragments "f" belong.}
}
\value{
\itemize{
  \item \code{shannon}: Shannon's total Entropy.
  \item \code{within}: Within groups entropy.
  \item \code{between}: Between groups entropy.
  \item \code{groups}: A data frame with information about each group: relative frequency, internal entropy and number of species.
}
}
\description{
Computes Shannon diversity and its decomposition
}
\examples{
data(Qesem_s)
data(Qesem_f)
shannon_frag(Qesem_s$HU, Qesem_s$Group, Qesem_f$HU, Qesem_f$Group)

}
\references{
Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
}
\seealso{
\link{shannon}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bs.R
\name{bs}
\alias{bs}
\title{Bootstrap estimates of the diversity indices}
\usage{
bs(x, ind = "shannon", B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}

\item{ind}{Index to be computed. The default value is "shannon". Other possible values are: "simpson_E", "simpson_D", "menhinick", "margalef", "evenness", "equitability" and "dominance".}

\item{B}{Number of bootstrap samples. The default is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default is 0.95.}
}
\value{
\itemize{
  \item \code{s}: Boostrap standard error.
  \item \code{low}: Lower limit of the confidence interval.
  \item \code{up}: Upper limit of the confidence interval.
}
}
\description{
Computes bootstrap standard error and confidence interval of the diversity indices
}
\examples{
data(Qesem_s)
bs(Qesem_s$HU)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bs.R
\name{bs}
\alias{bs}
\title{Bootstrap estimates of the diversity indices}
\usage{
bs(x, ind = "shannon", B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed.}

\item{ind}{Index to be computed. The default value is "shannon". Other possible values are: "simpson_E", "simpson_D", "menhinick", "margalef", "evenness", "equitability" and "dominance".}

\item{B}{Number of bootstrap samples. The default is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default is 0.95.}
}
\value{
\itemize{
  \item \code{s}: Boostrap standard error.
  \item \code{ci}: Confidence interval.
}
}
\description{
Computes bootstrap standard error and confidence interval of the diversity indices
}
\examples{
data(Qesem_s)
bs(Qesem_s$HU)

}
\references{
Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
}
\seealso{
\link{shannon}, \link{dec_shannon}, \link{dominance}, \link{equitability}, \link{evenness}, \link{margalef}, \link{menhinick}, \link{simpson_D}, \link{simpson_E}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_x.R
\name{check_x}
\alias{check_x}
\title{Check input}
\usage{
check_x(x)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}
}
\value{
x without NA or 0 values
}
\description{
Checks if x is a proper input
}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_x.R
\name{check_x}
\alias{check_x}
\title{Check input}
\usage{
check_x(x)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species. NA values are allowed.}
}
\value{
x without NA or 0 values
}
\description{
Checks if x is a proper input
}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dominance.R
\name{dominance}
\alias{dominance}
\title{Dominance index}
\usage{
dominance(x)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}
}
\value{
Dominance index (Modified Simpson's dominance index).
}
\description{
Modification of the Simpson's dominance index to be restricted between 0 and 1.
}
\examples{
data(Qesem_s)
dominance(Qesem_s$HU)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
\seealso{
\link{simpson_D}
}
